aliyun
    * ``auth_key_id`` Specify access key id for authentication

    * ``auth_secret`` Specify access secret for authentication


.. note::
   
   Aliyun Provider requires an access key id and access secret with full rights on dns.
   Better to use RAM on Aliyun cloud to create a specified user for the dns operation.
   The referrence for Aliyun DNS production:
   https://help.aliyun.com/product/29697.html

